package Bundle::WATERKIP::CLI::JWT;
our $VERSION = '0.003';
use Moo;
use namespace::autoclean;

# ABSTRACT: Bundle::WATERKIP::Azure get Azure JWT tokens

extends 'YA::CLI';

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Bundle::WATERKIP::CLI::JWT - Bundle::WATERKIP::Azure get Azure JWT tokens

=head1 VERSION

version 0.003

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 ATTRIBUTES

=head1 METHODS

=head1 AUTHOR

Wesley Schwengle <waterkip@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2024 by Wesley Schwengle.

This is free software, licensed under:

  The (three-clause) BSD License

=cut
