use utf8;
package Bundle::WATERKIP;
our $VERSION = '0.003';

# ABSTRACT: A mono repo for perl scripts and modules which WATERKIP likes

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Bundle::WATERKIP - A mono repo for perl scripts and modules which WATERKIP likes

=head1 VERSION

version 0.003

=head1 SYNOPSIS

    cpanm Bundle::WATERKIP

=head1 DESCRIPTION

This module serves a simple purpose. It is the main repository for all Perl
related things WATERKIP has come to rely on. It installs modules that I want
for development purposes. And it ships the bin scripts I want to have on my
machines.

=head1 SEE ALSO

If you want to know what is installed, see the dependencies :)

=head1 AUTHOR

Wesley Schwengle <waterkip@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2024 by Wesley Schwengle.

This is free software, licensed under:

  The (three-clause) BSD License

=cut
